# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from testit_api_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from testit_api_client.model.attachment_change_view_model import AttachmentChangeViewModel
from testit_api_client.model.attachment_change_view_model_array_work_item_changed_field_view_model import AttachmentChangeViewModelArrayWorkItemChangedFieldViewModel
from testit_api_client.model.attachment_model import AttachmentModel
from testit_api_client.model.attachment_model_auto_test_step_results_model import AttachmentModelAutoTestStepResultsModel
from testit_api_client.model.attachment_put_model import AttachmentPutModel
from testit_api_client.model.attachment_put_model_auto_test_step_results_model import AttachmentPutModelAutoTestStepResultsModel
from testit_api_client.model.attachment_sub_get_model import AttachmentSubGetModel
from testit_api_client.model.auto_test_average_duration_model import AutoTestAverageDurationModel
from testit_api_client.model.auto_test_change_view_model import AutoTestChangeViewModel
from testit_api_client.model.auto_test_change_view_model_array_work_item_changed_field_view_model import AutoTestChangeViewModelArrayWorkItemChangedFieldViewModel
from testit_api_client.model.auto_test_id_model import AutoTestIdModel
from testit_api_client.model.auto_test_model import AutoTestModel
from testit_api_client.model.auto_test_model_v2_get_model import AutoTestModelV2GetModel
from testit_api_client.model.auto_test_namespace_model import AutoTestNamespaceModel
from testit_api_client.model.auto_test_post_model import AutoTestPostModel
from testit_api_client.model.auto_test_put_model import AutoTestPutModel
from testit_api_client.model.auto_test_results_for_test_run_model import AutoTestResultsForTestRunModel
from testit_api_client.model.auto_test_short_model import AutoTestShortModel
from testit_api_client.model.auto_test_step_model import AutoTestStepModel
from testit_api_client.model.autotest_filter_model import AutotestFilterModel
from testit_api_client.model.autotest_historical_result_select_model import AutotestHistoricalResultSelectModel
from testit_api_client.model.autotest_result_historical_get_model import AutotestResultHistoricalGetModel
from testit_api_client.model.autotest_result_outcome import AutotestResultOutcome
from testit_api_client.model.autotest_result_reason_sub_get_model import AutotestResultReasonSubGetModel
from testit_api_client.model.autotest_select_model import AutotestSelectModel
from testit_api_client.model.autotests_extraction_model import AutotestsExtractionModel
from testit_api_client.model.autotests_select_model import AutotestsSelectModel
from testit_api_client.model.available_test_result_outcome import AvailableTestResultOutcome
from testit_api_client.model.boolean_nullable_test_plan_changed_field_view_model import BooleanNullableTestPlanChangedFieldViewModel
from testit_api_client.model.boolean_test_plan_changed_field_view_model import BooleanTestPlanChangedFieldViewModel
from testit_api_client.model.boolean_work_item_changed_field_view_model import BooleanWorkItemChangedFieldViewModel
from testit_api_client.model.configuration_by_parameters_model import ConfigurationByParametersModel
from testit_api_client.model.configuration_model import ConfigurationModel
from testit_api_client.model.configuration_post_model import ConfigurationPostModel
from testit_api_client.model.configuration_put_model import ConfigurationPutModel
from testit_api_client.model.configuration_select_model import ConfigurationSelectModel
from testit_api_client.model.custom_attribute_change_model import CustomAttributeChangeModel
from testit_api_client.model.custom_attribute_get_model import CustomAttributeGetModel
from testit_api_client.model.custom_attribute_model import CustomAttributeModel
from testit_api_client.model.custom_attribute_option_model import CustomAttributeOptionModel
from testit_api_client.model.custom_attribute_option_post_model import CustomAttributeOptionPostModel
from testit_api_client.model.custom_attribute_post_model import CustomAttributePostModel
from testit_api_client.model.custom_attribute_put_model import CustomAttributePutModel
from testit_api_client.model.custom_attribute_search_query_model import CustomAttributeSearchQueryModel
from testit_api_client.model.custom_attribute_template_model import CustomAttributeTemplateModel
from testit_api_client.model.custom_attribute_template_post_model import CustomAttributeTemplatePostModel
from testit_api_client.model.custom_attribute_template_put_model import CustomAttributeTemplatePutModel
from testit_api_client.model.custom_attribute_template_search_query_model import CustomAttributeTemplateSearchQueryModel
from testit_api_client.model.custom_attribute_test_plan_project_relation_put_model import CustomAttributeTestPlanProjectRelationPutModel
from testit_api_client.model.custom_attribute_types_enum import CustomAttributeTypesEnum
from testit_api_client.model.date_range_model import DateRangeModel
from testit_api_client.model.date_time_range_selector_model import DateTimeRangeSelectorModel
from testit_api_client.model.external_link_model import ExternalLinkModel
from testit_api_client.model.failure_category_model import FailureCategoryModel
from testit_api_client.model.failure_class_model import FailureClassModel
from testit_api_client.model.failure_class_regex_model import FailureClassRegexModel
from testit_api_client.model.filter_model import FilterModel
from testit_api_client.model.flaky_bulk_model import FlakyBulkModel
from testit_api_client.model.get_xlsx_test_points_by_test_plan_model import GetXlsxTestPointsByTestPlanModel
from testit_api_client.model.global_custom_attribute_post_model import GlobalCustomAttributePostModel
from testit_api_client.model.global_custom_attribute_update_model import GlobalCustomAttributeUpdateModel
from testit_api_client.model.guid_extraction_model import GuidExtractionModel
from testit_api_client.model.guid_work_item_changed_field_view_model import GuidWorkItemChangedFieldViewModel
from testit_api_client.model.image_resize_type import ImageResizeType
from testit_api_client.model.int32_range_selector_model import Int32RangeSelectorModel
from testit_api_client.model.int32_work_item_changed_field_view_model import Int32WorkItemChangedFieldViewModel
from testit_api_client.model.int64_range_selector_model import Int64RangeSelectorModel
from testit_api_client.model.int64_work_item_changed_field_view_model import Int64WorkItemChangedFieldViewModel
from testit_api_client.model.iteration_model import IterationModel
from testit_api_client.model.iteration_put_model import IterationPutModel
from testit_api_client.model.label_post_model import LabelPostModel
from testit_api_client.model.label_short_model import LabelShortModel
from testit_api_client.model.last_test_result_model import LastTestResultModel
from testit_api_client.model.link_model import LinkModel
from testit_api_client.model.link_post_model import LinkPostModel
from testit_api_client.model.link_put_model import LinkPutModel
from testit_api_client.model.link_sub_get_model import LinkSubGetModel
from testit_api_client.model.link_type import LinkType
from testit_api_client.model.no_content_result import NoContentResult
from testit_api_client.model.notification_model import NotificationModel
from testit_api_client.model.notification_query_filter_model import NotificationQueryFilterModel
from testit_api_client.model.notification_type_model import NotificationTypeModel
from testit_api_client.model.parameter_group_model import ParameterGroupModel
from testit_api_client.model.parameter_iteration_model import ParameterIterationModel
from testit_api_client.model.parameter_model import ParameterModel
from testit_api_client.model.parameter_post_model import ParameterPostModel
from testit_api_client.model.parameter_put_model import ParameterPutModel
from testit_api_client.model.parameter_short_model import ParameterShortModel
from testit_api_client.model.period_view_model import PeriodViewModel
from testit_api_client.model.period_view_model_test_plan_changed_field_view_model import PeriodViewModelTestPlanChangedFieldViewModel
from testit_api_client.model.problem_details import ProblemDetails
from testit_api_client.model.project_attributes_filter_model import ProjectAttributesFilterModel
from testit_api_client.model.project_custom_attribute_template_get_model import ProjectCustomAttributeTemplateGetModel
from testit_api_client.model.project_custom_attributes_templates_filter_model import ProjectCustomAttributesTemplatesFilterModel
from testit_api_client.model.project_export_query_model import ProjectExportQueryModel
from testit_api_client.model.project_export_with_test_plans_post_model import ProjectExportWithTestPlansPostModel
from testit_api_client.model.project_model import ProjectModel
from testit_api_client.model.project_post_model import ProjectPostModel
from testit_api_client.model.project_put_model import ProjectPutModel
from testit_api_client.model.project_shortest_model import ProjectShortestModel
from testit_api_client.model.projects_filter_model import ProjectsFilterModel
from testit_api_client.model.public_test_point_model import PublicTestPointModel
from testit_api_client.model.public_test_run_model import PublicTestRunModel
from testit_api_client.model.request_type_model import RequestTypeModel
from testit_api_client.model.search_auto_tests_query_includes_model import SearchAutoTestsQueryIncludesModel
from testit_api_client.model.search_custom_attribute_template_get_model import SearchCustomAttributeTemplateGetModel
from testit_api_client.model.search_webhooks_query_model import SearchWebhooksQueryModel
from testit_api_client.model.section_model import SectionModel
from testit_api_client.model.section_move_model import SectionMoveModel
from testit_api_client.model.section_post_model import SectionPostModel
from testit_api_client.model.section_put_model import SectionPutModel
from testit_api_client.model.section_rename_model import SectionRenameModel
from testit_api_client.model.section_with_steps_model import SectionWithStepsModel
from testit_api_client.model.shared_step_change_view_model import SharedStepChangeViewModel
from testit_api_client.model.shared_step_model import SharedStepModel
from testit_api_client.model.shared_step_reference_model import SharedStepReferenceModel
from testit_api_client.model.shared_step_reference_section_model import SharedStepReferenceSectionModel
from testit_api_client.model.shared_step_reference_sections_query_filter_model import SharedStepReferenceSectionsQueryFilterModel
from testit_api_client.model.shared_step_references_query_filter_model import SharedStepReferencesQueryFilterModel
from testit_api_client.model.shared_step_result_model import SharedStepResultModel
from testit_api_client.model.short_configuration import ShortConfiguration
from testit_api_client.model.step_comment_model import StepCommentModel
from testit_api_client.model.step_model import StepModel
from testit_api_client.model.step_put_model import StepPutModel
from testit_api_client.model.step_result_model import StepResultModel
from testit_api_client.model.string_array_test_plan_changed_field_view_model import StringArrayTestPlanChangedFieldViewModel
from testit_api_client.model.string_array_work_item_changed_field_view_model import StringArrayWorkItemChangedFieldViewModel
from testit_api_client.model.string_test_plan_changed_field_view_model import StringTestPlanChangedFieldViewModel
from testit_api_client.model.string_work_item_changed_field_view_model import StringWorkItemChangedFieldViewModel
from testit_api_client.model.tag_short_model import TagShortModel
from testit_api_client.model.test_plan_change_model import TestPlanChangeModel
from testit_api_client.model.test_plan_changed_fields_view_model import TestPlanChangedFieldsViewModel
from testit_api_client.model.test_plan_group_by_status import TestPlanGroupByStatus
from testit_api_client.model.test_plan_group_by_test_suite import TestPlanGroupByTestSuite
from testit_api_client.model.test_plan_group_by_tester import TestPlanGroupByTester
from testit_api_client.model.test_plan_group_by_tester_and_status import TestPlanGroupByTesterAndStatus
from testit_api_client.model.test_plan_link import TestPlanLink
from testit_api_client.model.test_plan_model import TestPlanModel
from testit_api_client.model.test_plan_post_model import TestPlanPostModel
from testit_api_client.model.test_plan_put_model import TestPlanPutModel
from testit_api_client.model.test_plan_search_query_model import TestPlanSearchQueryModel
from testit_api_client.model.test_plan_short_model import TestPlanShortModel
from testit_api_client.model.test_plan_status_model import TestPlanStatusModel
from testit_api_client.model.test_plan_with_analytic_model import TestPlanWithAnalyticModel
from testit_api_client.model.test_plan_with_test_suite_tree_model import TestPlanWithTestSuiteTreeModel
from testit_api_client.model.test_point_analytic_result import TestPointAnalyticResult
from testit_api_client.model.test_point_by_test_suite_model import TestPointByTestSuiteModel
from testit_api_client.model.test_point_change_view_model import TestPointChangeViewModel
from testit_api_client.model.test_point_change_view_model_test_plan_changed_field_view_model import TestPointChangeViewModelTestPlanChangedFieldViewModel
from testit_api_client.model.test_point_filter_model import TestPointFilterModel
from testit_api_client.model.test_point_put_model import TestPointPutModel
from testit_api_client.model.test_point_result_model import TestPointResultModel
from testit_api_client.model.test_point_selector import TestPointSelector
from testit_api_client.model.test_point_short_get_model import TestPointShortGetModel
from testit_api_client.model.test_point_short_model import TestPointShortModel
from testit_api_client.model.test_point_status import TestPointStatus
from testit_api_client.model.test_point_with_last_result_model import TestPointWithLastResultModel
from testit_api_client.model.test_result_change_view_model import TestResultChangeViewModel
from testit_api_client.model.test_result_change_view_model_test_plan_changed_field_view_model import TestResultChangeViewModelTestPlanChangedFieldViewModel
from testit_api_client.model.test_result_chronology_model import TestResultChronologyModel
from testit_api_client.model.test_result_history_report_model import TestResultHistoryReportModel
from testit_api_client.model.test_result_model import TestResultModel
from testit_api_client.model.test_result_outcome import TestResultOutcome
from testit_api_client.model.test_result_short_get_model import TestResultShortGetModel
from testit_api_client.model.test_result_short_model import TestResultShortModel
from testit_api_client.model.test_result_step_comment_put_model import TestResultStepCommentPutModel
from testit_api_client.model.test_result_update_model import TestResultUpdateModel
from testit_api_client.model.test_result_v2_get_model import TestResultV2GetModel
from testit_api_client.model.test_result_v2_short_model import TestResultV2ShortModel
from testit_api_client.model.test_results_filter_model import TestResultsFilterModel
from testit_api_client.model.test_results_local_filter_model import TestResultsLocalFilterModel
from testit_api_client.model.test_results_statistics_get_model import TestResultsStatisticsGetModel
from testit_api_client.model.test_run_analytic_result_model import TestRunAnalyticResultModel
from testit_api_client.model.test_run_fill_by_auto_tests_post_model import TestRunFillByAutoTestsPostModel
from testit_api_client.model.test_run_fill_by_configurations_post_model import TestRunFillByConfigurationsPostModel
from testit_api_client.model.test_run_fill_by_work_items_post_model import TestRunFillByWorkItemsPostModel
from testit_api_client.model.test_run_filter_model import TestRunFilterModel
from testit_api_client.model.test_run_group_by_failure_class_model import TestRunGroupByFailureClassModel
from testit_api_client.model.test_run_group_by_status_model import TestRunGroupByStatusModel
from testit_api_client.model.test_run_model import TestRunModel
from testit_api_client.model.test_run_search_query_model import TestRunSearchQueryModel
from testit_api_client.model.test_run_short_get_model import TestRunShortGetModel
from testit_api_client.model.test_run_short_model import TestRunShortModel
from testit_api_client.model.test_run_state import TestRunState
from testit_api_client.model.test_run_statistics_error_categories_get_model import TestRunStatisticsErrorCategoriesGetModel
from testit_api_client.model.test_run_statistics_statuses_get_model import TestRunStatisticsStatusesGetModel
from testit_api_client.model.test_run_test_results_partial_bulk_set_model import TestRunTestResultsPartialBulkSetModel
from testit_api_client.model.test_run_test_results_select_model import TestRunTestResultsSelectModel
from testit_api_client.model.test_run_v2_get_model import TestRunV2GetModel
from testit_api_client.model.test_run_v2_post_short_model import TestRunV2PostShortModel
from testit_api_client.model.test_run_v2_put_model import TestRunV2PutModel
from testit_api_client.model.test_suite_change_view_model import TestSuiteChangeViewModel
from testit_api_client.model.test_suite_change_view_model_test_plan_changed_field_view_model import TestSuiteChangeViewModelTestPlanChangedFieldViewModel
from testit_api_client.model.test_suite_v2_get_model import TestSuiteV2GetModel
from testit_api_client.model.test_suite_v2_post_model import TestSuiteV2PostModel
from testit_api_client.model.test_suite_v2_put_model import TestSuiteV2PutModel
from testit_api_client.model.test_suite_v2_tree_model import TestSuiteV2TreeModel
from testit_api_client.model.test_suite_with_children_model import TestSuiteWithChildrenModel
from testit_api_client.model.test_suite_work_items_search_model import TestSuiteWorkItemsSearchModel
from testit_api_client.model.user_rank_model import UserRankModel
from testit_api_client.model.user_with_rank_model import UserWithRankModel
from testit_api_client.model.validate_anti_forgery_token_attribute import ValidateAntiForgeryTokenAttribute
from testit_api_client.model.validation_problem_details import ValidationProblemDetails
from testit_api_client.model.web_hook_event_type import WebHookEventType
from testit_api_client.model.web_hook_event_type_model import WebHookEventTypeModel
from testit_api_client.model.web_hook_log_model import WebHookLogModel
from testit_api_client.model.web_hook_model import WebHookModel
from testit_api_client.model.web_hook_post_model import WebHookPostModel
from testit_api_client.model.work_item_change_model import WorkItemChangeModel
from testit_api_client.model.work_item_changed_attribute_view_model import WorkItemChangedAttributeViewModel
from testit_api_client.model.work_item_changed_fields_view_model import WorkItemChangedFieldsViewModel
from testit_api_client.model.work_item_comment_model import WorkItemCommentModel
from testit_api_client.model.work_item_comment_post_model import WorkItemCommentPostModel
from testit_api_client.model.work_item_comment_put_model import WorkItemCommentPutModel
from testit_api_client.model.work_item_entity_types import WorkItemEntityTypes
from testit_api_client.model.work_item_filter_model import WorkItemFilterModel
from testit_api_client.model.work_item_id_model import WorkItemIdModel
from testit_api_client.model.work_item_identifier_model import WorkItemIdentifierModel
from testit_api_client.model.work_item_like_model import WorkItemLikeModel
from testit_api_client.model.work_item_link_change_view_model import WorkItemLinkChangeViewModel
from testit_api_client.model.work_item_link_change_view_model_array_work_item_changed_field_view_model import WorkItemLinkChangeViewModelArrayWorkItemChangedFieldViewModel
from testit_api_client.model.work_item_model import WorkItemModel
from testit_api_client.model.work_item_move_post_model import WorkItemMovePostModel
from testit_api_client.model.work_item_post_model import WorkItemPostModel
from testit_api_client.model.work_item_priority_model import WorkItemPriorityModel
from testit_api_client.model.work_item_put_model import WorkItemPutModel
from testit_api_client.model.work_item_search_query_model import WorkItemSearchQueryModel
from testit_api_client.model.work_item_select_model import WorkItemSelectModel
from testit_api_client.model.work_item_short_model import WorkItemShortModel
from testit_api_client.model.work_item_states import WorkItemStates
from testit_api_client.model.work_item_step_change_view_model import WorkItemStepChangeViewModel
from testit_api_client.model.work_item_step_change_view_model_array_work_item_changed_field_view_model import WorkItemStepChangeViewModelArrayWorkItemChangedFieldViewModel
from testit_api_client.model.work_item_version_model import WorkItemVersionModel
from testit_api_client.model.work_items_extraction_model import WorkItemsExtractionModel
